@@ -13,6 +13,7 @@ our @EXPORT = (
     qw/
        debug
        slurp
+       spew
        textRenderTemplate
        /);
 
@@ -99,6 +100,24 @@ sub slurp {
 
 
 
+=head2 spew($file, $text)
+
+Crete a new $file a and print $text to it.
+
+Return 1 on success, else 0.
+
+=cut
+sub spew {
+	my ($file, $text) = @_;
+    open(my $fh, ">", $file) or return 0;
+    print $fh $text or return 0;
+    return 1;
+}
+
+
+
+
+
 =head2 textRenderTemplate($template, $rhParam)
 
 Replace the keys in $rhParam with the values in $rhParam, for
